@@ -8,12 +8,13 @@
 import threading
 import time
 import rsa
+import random
 from hashlib import md5
 from i2cylib.network.i2tcp_basic import I2TCPclient
 from i2cylib.crypto.iccode import Iccode
 from i2cylib.utils import random_keygen
 
-VERSION = "2.0"
+VERSION = "2.1"
 
 
 class Client(I2TCPclient):
@@ -64,7 +65,7 @@ class Client(I2TCPclient):
         if self.flag_secured_connection_built:  # 安全连接加密
             assert isinstance(self.coder_pack, Iccode)
             while self.flag_pack_busy:
-                time.sleep(0.0001)
+                time.sleep(0.001)
             self.flag_pack_busy = True
             self.coder_pack.reset()
             data = self.coder_pack.encode(data)
@@ -72,15 +73,19 @@ class Client(I2TCPclient):
 
         left = length
         header_unit = self.version + self.keygen.key
+        package_id = bytes((random.randint(0, 255),))
         while left > 0:
             pak = b"A" + left.to_bytes(length=3, byteorder='big', signed=False)
-            if left < 60000:
+            if left < 32758:
                 left = 0
             else:
-                left -= 60000
+                left -= 32758
             pak_length = length - left - offset
             pak += pak_length.to_bytes(length=2, byteorder='big', signed=False)
-            pak += md5(pak + header_unit).digest()[:3]
+            pak += bytes((md5(pak + header_unit).digest()[2],))
+            payload_sum = md5(data[offset:length - left]).digest()[:2]
+            pak += payload_sum
+            pak += package_id
             pak += data[offset:length - left]
             offset = length - left
             paks.append(pak)
@@ -117,7 +122,7 @@ class Client(I2TCPclient):
             if self.flag_secured_connection_built:  # 安全连接解密
                 assert isinstance(self.coder_depack, Iccode)
                 while self.flag_depack_busy and self.live:
-                    time.sleep(0.0001)
+                    time.sleep(0.001)
                 if package:
                     self.flag_depack_busy = True
                     self.coder_depack.reset()
@@ -157,6 +162,7 @@ class Client(I2TCPclient):
     def send(self, data):
         """
         send data to server 向I2TCP服务器发送数据
+        it is recommended that data length to be timed by 32758 bytes 推荐单次发送大小位32758的整数倍
 
         :param data: bytes, data to send (smaller than 16MB) 待发送的数据
         :return: int, total amount of bytes that has been sent 发送出去的总大小
@@ -165,7 +171,7 @@ class Client(I2TCPclient):
 
     def get(self, header=None, timeout=0):
         """
-        get one package with specified header(or not)  从缓冲池中获取数据包（可指定包头部进行筛选）
+        get one package with specified header(or not)  从缓冲池中获取数据包（可指定包头部进行筛选）若超时则返回None
 
         :param timeout: int, timeout for receiving specified header  超时时间
         :param header: bytes, package header  包头部，可不指定
@@ -184,7 +190,7 @@ class Client(I2TCPclient):
 
             if timeout:
                 time.sleep(0.0001)
-            elif timeout == 0 or (time.time() - t) > timeout:
+            if timeout == 0 or (time.time() - t) > timeout:
                 break
 
         return ret
