@@ -24,15 +24,18 @@ if __name__ == '__main__':
     logger = Logger()
     srv = Server(port=24678, key=b"test", logger=logger, secured_connection=True)
     clt = Client(port=24678, hostname="127.0.0.1", key=b"test", logger=logger)
+    ex_clt = Client(port=24678, hostname="127.0.0.1", key=b"asds", logger=logger)
 
     srv.start()
+    ex_clt.connect()
+    time.sleep(1)
     clt.connect()
 
     data = b""
 
     logger.INFO("[main] generating random data to send")
-    for i in range(1024*256):
-        data += bytes((int(256*random.random()),))
+    for i in range(1024 * 256):
+        data += bytes((int(256 * random.random()),))
 
     for i in range(16):
         threading.Thread(target=massive_send, args=(clt, "A{}".format(i).encode() + data)).start()
