@@ -3,7 +3,7 @@
 # Author: i2cy(i2cy@outlook.com)
 # Filename: I2TCP_server
 # Created on: 2021/1/11
-
+import random
 import socket
 import threading
 import time
@@ -14,7 +14,7 @@ from i2cylib.crypto.iccode import Iccode
 from i2cylib.utils.logger import Logger
 from i2cylib.utils.bytes import random_keygen
 
-VERSION = "1.3"
+VERSION = "1.4"
 
 
 class I2TCPserver:
@@ -221,6 +221,7 @@ class I2TCPserver:
                     ret = self.connections[i]["handler"]
                     self.connections[i]["handled"] = True
                     break
+            time.sleep(0.001)
             if not wait:
                 break
 
@@ -286,15 +287,19 @@ class I2TCPhandler:
         length = len(data)
         left = length
         header_unit = self.version + self.keygen.key
+        package_id = bytes((random.randint(0, 255),))
         while left > 0:
             pak = b"A" + left.to_bytes(length=3, byteorder='big', signed=False)
-            if left < 60000:
+            if left < 32758:
                 left = 0
             else:
-                left -= 60000
+                left -= 32758
             pak_length = length - left - offset
             pak += pak_length.to_bytes(length=2, byteorder='big', signed=False)
-            pak += md5(pak + header_unit).digest()[:3]
+            pak += bytes((md5(pak + header_unit).digest()[2],))
+            payload_sum = md5(data[offset:length - left]).digest()[:2]
+            pak += payload_sum
+            pak += package_id
             pak += data[offset:length - left]
             offset = length - left
             paks.append(pak)
@@ -310,16 +315,18 @@ class I2TCPhandler:
 
         header_unit = self.version + self.keygen.key
         pak_type = pak_data[0]
-        ret = None
+
         if pak_type == ord("H"):
             ret = "heartbeat"
         elif pak_type == ord("A"):
             ret = {"total_length": int.from_bytes(pak_data[1:4], byteorder='big', signed=False),
                    "package_length": int.from_bytes(pak_data[4:6], byteorder='big', signed=False),
-                   "header_md5": pak_data[6:9],
-                   "data": pak_data[9:]}
-            header_md5 = md5(pak_data[0:6] + header_unit).digest()[:3]
-            if header_md5 != ret["header_md5"]:
+                   "header_sum": pak_data[6],
+                   "payload_sum": pak_data[7:9],
+                   "package_id": pak_data[9],
+                   "data": pak_data[10:]}
+            header_sum = md5(pak_data[0:6] + header_unit).digest()[2]
+            if header_sum != ret["header_sum"]:
                 ret = None
         else:
             ret = None
@@ -450,7 +457,10 @@ class I2TCPhandler:
             mix_sha256.update(key_sha256.digest() + rand_num)
             mix_coder = Iccode(mix_sha256.digest(), fingerprint_level=6)
 
-            dynamic_key = self.srv.recv(65536)
+            dynamic_key = b""
+            while len(dynamic_key) < 64:
+                dynamic_key += self.srv.recv(64 - len(dynamic_key))
+
             dynamic_key = mix_coder.decode(dynamic_key)
 
             if self.keygen.keymatch(dynamic_key):
@@ -458,9 +468,13 @@ class I2TCPhandler:
                 self.srv.sendall(self.version)
                 self.logger.DEBUG("{} authorized".format(self.log_header))
             else:
-                self.logger.WARNING("{} unauthorized connection, key received: {}".format(self.log_header,
-                                                                                          dynamic_key))
-            feedback = self.srv.recv(2)
+                # self.logger.WARNING("{} unauthorized connection, key received: {}".format(self.log_header,
+                #                                                                           dynamic_key))
+                raise Exception("unauthorized connection, key received: {}".format(dynamic_key))
+
+            feedback = b""
+            while len(feedback) < 2:
+                feedback += self.srv.recv(2 - len(feedback))
             if feedback != b"OK":
                 raise Exception("invalid feedback, {}".format(feedback))
 
@@ -479,7 +493,13 @@ class I2TCPhandler:
 
         ret = None
         while ret is None:
-            pak = self.srv.recv(9)
+            pak = b"\x00"
+            while pak[0] not in (72, 65):
+                pak = self.srv.recv(1)
+                if pak == b"":
+                    return None
+            while len(pak) < 10:
+                pak += self.srv.recv(10 - len(pak))
             self.logger.DEBUG("{} received package head: {}".format(self.log_header, pak))
             if pak == b"":
                 return None
@@ -492,19 +512,32 @@ class I2TCPhandler:
                 ret = None
 
         total_length = ret["total_length"]
+        package_id = ret["package_id"]
         self.logger.DEBUG("{} receiving data of total length {}".format(self.log_header,
                                                                         total_length))
 
         data = b""
         length = 0
+
         while length != ret["package_length"]:
             length = len(data)
             data += self.srv.recv(ret["package_length"] - length)
+        payload_sum = md5(data).digest()[:2]
+        if payload_sum != ret["payload_sum"]:
+            self.logger.WARNING("{} broken package received".format(self.log_header))
+            raise Exception("broken package")
         all_data = data
+
         while len(all_data) < total_length:
-            pak = self.srv.recv(9)
+            pak = b"\x00"
+            while pak[0] not in (72, 65):
+                pak = self.srv.recv(1)
+                if pak == b"":
+                    return None
+            while len(pak) < 10:
+                pak += self.srv.recv(10 - len(pak))
             ret = self._depacker(pak)
-            if ret is None:
+            if ret is None or package_id != ret["package_id"] or total_length - len(all_data) != ret["total_length"]:
                 raise Exception("broken package")
             if ret == "heartbeat":
                 self.logger.DEBUG("{} heartbeat received".format(self.log_header))
@@ -514,8 +547,15 @@ class I2TCPhandler:
             while length != ret["package_length"]:
                 length = len(data)
                 data += self.srv.recv(ret["package_length"] - length)
+            payload_sum = md5(data).digest()[:2]
+            if payload_sum != ret["payload_sum"]:
+                self.logger.WARNING("{} broken package received".format(self.log_header))
+                raise Exception("broken package")
             all_data += data
 
+        if len(all_data) != total_length:
+            raise Exception("broken package")
+
         self._feed_watchdog()
         return all_data
 
